# Generated by Django 2.2.4 on 2021-04-03 13:31

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('schools', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Subscription',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('school_subscription', models.BooleanField(default=False)),
                ('individual_subscription', models.BooleanField(default=False)),
                ('is_paid', models.BooleanField(default=False)),
                ('is_paused', models.BooleanField(default=False)),
                ('school', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='schools.School')),
            ],
        ),
    ]



# Generated by Django 2.2.4 on 2019-09-15 14:59

import django.db.models.deletion
import schools.models
from django.db import migrations, models



class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Authority',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('authority_name', models.CharField(max_length=100)),
            ],
        ),
        migrations.CreateModel(
            name='School',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('school_name', models.CharField(default='', max_length=150)),
                ('school_type', models.CharField(choices=[('Primary', 'Primary school'), ('Secondary', 'Secondary school'), ('All', 'All through 5-18 school')], default='Primary', max_length=150)),
                ('active_account', models.BooleanField(default=True)),
                ('account_expiry', models.DateField(blank=True, default=schools.models.expiry_plus_28_days)),
                ('account_type', models.CharField(choices=[('Test', 'Test'), ('Demo', 'Demo'), ('Full', 'Full')], default='Full', max_length=10)),
                ('postcode', models.CharField(blank=True, default='', max_length=8)),
                ('is_departmental_school', models.BooleanField(default=False)),
                ('school_badge', models.ImageField(blank=True, null=True, upload_to=schools.models.BadgeUploadPath())),
                ('self_evaluation_last_visit', models.DateField(blank=True, default=None, null=True)),
                ('stakeholder_surveys_last_visit', models.DateField(blank=True, default=None, null=True)),
                ('improvement_plan_last_visit', models.DateField(blank=True, default=None, null=True)),
                ('authority', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='schools.Authority')),
            ],
        ),
        migrations.CreateModel(
            name='Faculty',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('faculty_name', models.CharField(default='', max_length=100)),
                ('owner', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='schools.School')),
            ],
        ),
    ]



# Generated by Django 2.2.4 on 2021-04-04 13:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schools', '0004_subscription_user'),
    ]

    operations = [
        migrations.AddField(
            model_name='school',
            name='school_code',
            field=models.CharField(default='--------', max_length=8),
        ),
    ]



# Generated by Django 2.2.4 on 2021-04-03 13:35

import schools.models
from django.db import migrations, models



class Migration(migrations.Migration):

    dependencies = [
        ('schools', '0002_subscription'),
    ]

    operations = [
        migrations.AddField(
            model_name='subscription',
            name='expiry',
            field=models.DateField(blank=True, default=schools.models.expiry_plus_28_days),
        ),
    ]



from django.contrib import admin
from import_export import resources, fields
from import_export.admin import ImportExportModelAdmin
from import_export.widgets import ForeignKeyWidget
from schools.models import School, Authority, Faculty, Subscription
from users.models import User


class SchoolResource(resources.ModelResource):

    authority = fields.Field(
        column_name='authority',
        attribute='authority',
        widget=ForeignKeyWidget(Authority, 'authority_name')
    )

    class Meta:
        model = School

class SchoolAdmin(ImportExportModelAdmin):
    resource_class = SchoolResource
    readonly_fields = ('id',)

    def get_list_display(self, request):
        return('school_name', 'authority', 'account_expiry')

class FacultyAdmin(ImportExportModelAdmin):
    pass


class AuthorityAdmin(ImportExportModelAdmin):
    pass

class SubscriptionResource(resources.ModelResource):

    school = fields.Field(
        column_name='school_name',
        attribute='school',
        widget=ForeignKeyWidget(School, 'school_name')
    )

    user = fields.Field(
        column_name='user',
        attribute='user',
        widget=ForeignKeyWidget(User, 'username')
    )

    class Meta:
        model = Subscription

class SubscriptionAdmin(ImportExportModelAdmin):
    resource_class = SubscriptionResource

    def get_list_display(self, request):
        return '__str__', 'school', 'school_subscription', 'individual_subscription', 'is_paid', 'expiry'

    list_filter = ['school_subscription', 'individual_subscription', 'school', 'is_paid']

    search_fields = ['school__school_name', 'user__username']



admin.site.register(School, SchoolAdmin)
admin.site.register(Faculty, FacultyAdmin)
admin.site.register(Authority, AuthorityAdmin)
admin.site.register(Subscription, SubscriptionAdmin)



from django.db import models
from datetime import datetime, timedelta
import os
from django.utils.deconstruct import deconstructible
from common.common_helpers import get_todays_date, get_random_identifier

from django.db.models import Q

SCHOOL_TYPE = [('Primary', 'Primary school'), ('Secondary', 'Secondary school'), ('All', 'All through 5-18 school')]
ACCOUNT_TYPE = [('Test', 'Test'), ('Demo', 'Demo'), ('Full', 'Full')]


class AuthorityManager(models.Manager):

    def get_all_authorities(self):
        return self.all().order_by('authority_name')

class Authority(models.Model):
    authority_name = models.CharField(max_length=100)
    objects = AuthorityManager()

    def __str__(self):
        return self.authority_name

def expiry_plus_one_year():
    return (datetime.today() + timedelta(days=365)).date()

def expiry_plus_28_days():
    return (datetime.today() + timedelta(days=28)).date()


def current_date_time():
    return datetime.today()

class SchoolManager(models.Manager):

    def new_school_account(self, school_name, authority, school_type):

        school_code = get_random_identifier(8)

        new_school_account = self.model(
            school_name=school_name,
            authority=authority,
            school_type=school_type,
            school_code=school_code
        )

        new_school_account.save()

        return new_school_account

    def get_all_schools(self):
        return self.all().order_by('school_name')

    def get_school(self, school_pk):

        return self.get(
            pk=school_pk
        )


    def update_stakeholder_surveys_visit(self, school):
        visit_time = datetime.today()
        school.stakeholder_surveys_last_visit = visit_time
        school.save()

    def update_self_evaluation_visit(self, school):
        visit_time = datetime.today()
        school.self_evaluation_last_visit = visit_time
        school.save()

    def update_improvement_plan_visit(self, school):
        visit_time = datetime.today()
        school.improvement_plan_last_visit = visit_time
        school.save()


    def school_postcode_exists(self, postcode):


        if postcode is not None:
            postcode = postcode.replace(' ', '').upper()

        return self.filter(
            postcode=postcode
        ).exists()

    def school_code_exists(self, school_code):

        try:
            self.get(
                school_code=school_code
            )
            return True
        except self.model.DoesNotExist:
            return False

    def get_school_by_school_code(self, school_code):
        return self.get(school_code=school_code)



    def get_schools_by_postcode(self, postcode):

        if postcode is not None:
            postcode = postcode.replace(' ', '').upper()

        if self.school_postcode_exists(postcode):

            return self.filter(
                postcode=postcode
            )
        return None


def lower_case_no_spaces(text):
    text.replace(' ', '-')
    text = text.lower()
    return text

@deconstructible
class BadgeUploadPath(object):

    def __call__(self, instance, filename):
        school_name_as_filename = lower_case_no_spaces(instance.school_name)
        ext = filename.split('.')[-1]
        filename = str(instance.pk) + '-' + school_name_as_filename + '.' + ext

        path = "images/badges"
        return os.path.join(path, filename)


class School(models.Model):
    school_name = models.CharField(max_length=150, default='')
    school_code = models.CharField(max_length=8, default='--------')
    school_type = models.CharField(max_length=150, choices=SCHOOL_TYPE, default='Primary')
    authority = models.ForeignKey(Authority, on_delete=models.CASCADE, blank=True, null=True)
    active_account = models.BooleanField(default=True)
    account_expiry = models.DateField(default=expiry_plus_28_days, blank=True)
    account_type = models.CharField(max_length=10, choices=ACCOUNT_TYPE, default='Full')
    postcode = models.CharField(max_length=8, default='', blank=True)
    is_departmental_school = models.BooleanField(default=False)
    school_badge = models.ImageField(upload_to=BadgeUploadPath(), null=True, blank=True)

    self_evaluation_last_visit = models.DateField(default=None, blank=True, null=True)
    stakeholder_surveys_last_visit = models.DateField(default=None, blank=True, null=True)
    improvement_plan_last_visit = models.DateField(default=None, blank=True, null=True)

    objects = SchoolManager()

    def __str__(self):
        return self.school_name



class FacultyManager(models.Manager):

    def get_faculty(self, pk):

        return self.get(
            pk=pk
        )

    # return faculties where owner is NULL (i.e. these are core Impact faculties)
    # or where owner is the current user's school
    def get_school_and_default_faculties(self, user):
        school_default_faculties = self.filter(
            Q(owner__isnull=True) |
            Q(owner=user.get_school()))
        return school_default_faculties

    # return faculties where ownereis the current user's school
    def get_school_faculties(self, user):
        return self.filter(owner=user.get_school()).order_by('faculty_name')

    def get_school_faculties_non_member(self, user):

        user_is_member = user.member_of_faculties.all()

        return self.filter(
            owner=user.get_school()
        ).exclude(id__in=user_is_member).order_by('faculty_name')


    def create_faculty(self, faculty_name, user):

        faculty = self.model(
            faculty_name=faculty_name,
            owner=user.get_school()
        )

        faculty.save()

        return faculty

    def update_faculty_name(self, faculty, faculty_name):

        faculty.faculty_name = faculty_name
        faculty.save()


    def delete(self, pk):
        faculty = self.get(pk=pk)
        faculty.delete()

    def get_school_as_faculty(self):
        return self.get(
            faculty_name='School',
            owner__isnull=True
        )

    def get_school_pk(self):

        return self.get(
            faculty_name = 'School'
        ).pk


class Faculty(models.Model):
    faculty_name = models.CharField(max_length=100, default='')
    owner = models.ForeignKey(School, on_delete=models.CASCADE, blank=True, null=True)

    objects = FacultyManager()

    def __str__(self):
        return self.faculty_name


class SubscriptionManager(models.Manager):

    def create_individual_subscription(self, user, school):

        new_individual_subscription = self.model(
            school=school,
            user=user,
            individual_subscription=True,
        )

        new_individual_subscription.save()

    def school_has_subscription(self, school):

        return self.filter(
            school=school,
            school_subscription=True,
            expiry__gte=get_todays_date()
        ).count() > 0

    def get_school_subscription(self, school):
        try:
            return self.filter(
                school=school,
                school_subscription=True
            ).order_by('expiry').last()

        except IndexError:
            return None

    def individual_has_subscription(self, user):

        return self.filter(
            user=user,
            individual_subscription=True,
            expiry__gte=get_todays_date()
        ).count() > 0

    def get_individual_subscription(self, user):
        try:
            return self.filter(
                user=user,
                individual_subscription=True
            ).order_by('expiry').last()

        except IndexError:
            return None

    def get_subscription_details(self, user):

        if self.school_has_subscription(user.school):
            return self.get_school_subscription(user.school)
        else:
            return self.get_individual_subscription(user)

class Subscription(models.Model):
    school = models.ForeignKey(School, on_delete=models.CASCADE, blank=True, null=True)

    school_subscription = models.BooleanField(default=False)
    individual_subscription = models.BooleanField(default=False)

    user = models.ForeignKey('users.User', on_delete=models.CASCADE, blank=True, null=True)

    expiry = models.DateField(default=expiry_plus_28_days, blank=True)

    is_paid = models.BooleanField(default=False)

    is_paused = models.BooleanField(default=False)

    objects = SubscriptionManager()

    def __str__(self):
        return self.school.school_name






from django.urls import path
from . import views





app_name = 'schools'
urlpatterns = [
    path('invite-users/', views.InviteUsers.as_view(), name='invite-users'),
    path('<str:sent>/invite-users/', views.InviteUsers.as_view(), name='invite-users'),

    path('manage-departments/', views.ManageDepartments.as_view(), name='manage-departments'),
    path('create-department/', views.CreateDepartment.as_view(), name='create-department'),
    path('<int:pk>/edit-department/', views.CreateDepartment.as_view(), name='edit-department'),
    path('<int:pk>/view-department/', views.ViewDepartment.as_view(), name='view-department'),
    path('<int:pk>/delete-department/', views.DeleteDepartment.as_view(), name='delete-department'),
    path('<int:pk>/<int:faculty_pk>/delete-department-user/', views.DeleteDepartmentUser.as_view(), name='delete-department-user'),

    path('user-join-department/', views.UserJoinDepartment.as_view(), name='user-join-department'),
    path('<int:faculty_pk>/user-leave-department/', views.user_leave_department, name='user-leave-department'),
    path('user-change-department/', views.UserChangeDepartment.as_view(), name='user-change-department'),
    path('user-edit-departments/', views.UserEditDepartments.as_view(), name='user-edit-departments'),

    path('account-expired/', views.AccountExpired.as_view(), name='account-expired'),

    path('schools:upload-school-badge/', views.UploadSchoolBadge.as_view(), name='upload-school-badge'),
        ]




# Generated by Django 2.2.4 on 2021-04-03 13:36

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('schools', '0003_subscription_expiry'),
    ]

    operations = [
        migrations.AddField(
            model_name='subscription',
            name='user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
    ]



from allauth.account.forms import SignupForm
from django.forms import Form, CharField, ModelForm

from schools.models import School, Faculty
from users.models import User



class InvitationSignupForm(SignupForm):

    def __init__(self, *args, **kwargs):
        super(InvitationSignupForm, self).__init__(*args, **kwargs)

    def save(self, request):
        user = super(InvitationSignupForm, self).save(request)
        school = School.objects.get(pk=self.school_id)
        user.school = school
        school_as_faculty = Faculty.objects.get_school_as_faculty()
        user.faculty = school_as_faculty
        user.save()
        return user


class DepartmentInvitationSignupForm(SignupForm):
    def __init__(self, *args, **kwargs):
        super(DepartmentInvitationSignupForm, self).__init__(*args, **kwargs)

    def save(self, request):
        user = super(DepartmentInvitationSignupForm, self).save(request)
        try:
            faculty = Faculty.objects.get(pk=self.faculty_id)
            user.school = faculty.owner
            user.faculty = faculty
            user.school_admin=False
            user.member_of_faculties.add(faculty)
        except Exception as e:
            print(e)

        user.save()
        return user

# Create a new user defined faculty
class NewDepartmentForm(ModelForm):

    class Meta:
        model = Faculty
        fields = ('faculty_name',)

    def __init__(self, *args, **kwargs):
        super(NewDepartmentForm, self).__init__(*args, **kwargs)
        self.fields['faculty_name'].widget.attrs['class'] = 'form-control'
        self.fields['faculty_name'].widget.attrs['placeholder'] = 'Department Name...'

    def set_initial(self, faculty_name):
        self.fields['faculty_name'].initial = faculty_name

    def clean_faculty(self):
        faculty_name = self.cleaned_data.get('faculty_name')
        return faculty_name


class DepartmentForm(ModelForm):

    class Meta:
        model = User
        fields = ('faculty',)

    def __init__(self, *args, **kwargs):
        super(DepartmentForm, self).__init__(*args, **kwargs)
        self.fields['faculty'].widget.attrs['class'] = 'form-control'
        self.fields['faculty'].empty_label = None

    def set_queryset(self, school_faculties):
        self.fields['faculty'].queryset = school_faculties

    def set_initial(self, current_faculty):
        self.fields['faculty'].initial = current_faculty

    def clean_faculty(self):
        return self.cleaned_data.get('faculty')


class SchoolBadgeForm(ModelForm):
    class Meta:
        model = School
        fields = ['school_badge']



from allauth.account.views import SignupView
from django.conf import settings
from django.contrib.auth.mixins import LoginRequiredMixin
from django.core.mail import EmailMessage
from django.http import HttpResponseRedirect
from django.shortcuts import redirect
from django.shortcuts import render
from django.template.loader import render_to_string
from django.urls import reverse
from django.urls import reverse_lazy
from django.utils.encoding import force_bytes, force_text
from django.utils.http import urlsafe_base64_encode, urlsafe_base64_decode
from django.views.generic import TemplateView
from django.views.generic.edit import DeleteView

from users.models import User
from .forms import NewDepartmentForm, DepartmentForm, SchoolBadgeForm
from .models import School, Faculty
from common import common_helpers
from config.settings.base import SIGNUP_PAGE


class InviteUsers(LoginRequiredMixin, TemplateView):
    template_name = 'schools/invite-users.html'

    def get(self, request, *args, **kwargs):

        school_code = request.user.school.school_code


        context = {
            'school_code': school_code,
            'signup_page': SIGNUP_PAGE
        }

        return render(request, self.template_name, context)


class ManageDepartments(LoginRequiredMixin, TemplateView):
    template_name = 'schools/manage-departments.html'

    def get(self, request, *args, **kwargs):

        faculty_list = []
        faculties = Faculty.objects.get_school_faculties(request.user)


        for faculty in faculties:
            member_count = User.objects.count_faculty_members(faculty)

            faculty_list.append({
                'faculty_pk': faculty.pk,
                'faculty_name': faculty.faculty_name,
                'member_count': member_count,

            })

        context = {
            'faculty_list': faculty_list,
        }

        return render(request, self.template_name, context)


class CreateDepartment(LoginRequiredMixin, TemplateView):
    template_name = 'schools/create-department.html'

    def get(self, request, *args, **kwargs):

        faculty_pk = kwargs.get('pk')

        new_department_form = NewDepartmentForm()

        if faculty_pk is not None:
            faculty = Faculty.objects.get_faculty(faculty_pk)
            new_department_form.set_initial(faculty.faculty_name)
            card_title = 'Edit Department'
        else:
            card_title = 'Create Department'

        context = {
            'new_department_form': new_department_form,
            'card_title': card_title
        }

        return render(request, self.template_name, context)

    def post(self, request, *args, **kwargs):
        faculty_pk = kwargs.get('pk')
        if 'save_faculty' in request.POST:



            new_department_form = NewDepartmentForm(request.POST)

            if new_department_form.is_valid():
                faculty_name = new_department_form.clean_faculty()

                if faculty_pk is None:
                    faculty = Faculty.objects.create_faculty(faculty_name, request.user)
                    faculty_pk = faculty.pk
                else:
                    faculty = Faculty.objects.get_faculty(faculty_pk)
                    Faculty.objects.update_faculty_name(faculty, faculty_name)

        return HttpResponseRedirect(reverse('schools:view-department', args=(faculty_pk,)))

class ViewDepartment(LoginRequiredMixin, TemplateView):
    template_name = 'schools/view-department.html'

    def get(self, request, *args, **kwargs):

        faculty_pk = kwargs.get('pk')
        faculty = Faculty.objects.get_faculty(faculty_pk)

        faculty_member_list = User.objects.get_faculty_members(faculty)
        print(faculty_member_list)

        context = {
            'faculty_member_list': faculty_member_list,
            'faculty': faculty,
            'program_name': settings.PROGRAM_NAME
        }

        return render(request, self.template_name, context)

    def post(self, request, *args, **kwargs):
        faculty_pk = kwargs.get('pk')
        faculty = Faculty.objects.get_faculty(faculty_pk)
        if 'remove-user' in request.POST:
            user_id = request.POST.get('user_id', None)
            print(user_id)

            user = User.objects.get(pk=user_id)
            user.remove_from_faculty(faculty_pk)

            return HttpResponseRedirect(reverse('schools:view-department', args=(faculty_pk,)))

class DeleteDepartment(LoginRequiredMixin, DeleteView):

    model = Faculty

    def get_success_url(self):
        return reverse_lazy('schools:manage-departments')

    def post(self, request, *args, **kwargs):
        if 'cancel' in request.POST:
            return HttpResponseRedirect(reverse('schools:manage-departments'))
        else:
            return super(DeleteDepartment, self).post(request, *args, **kwargs)

    def get_context_data(self, **kwargs):
        context = super(DeleteDepartment, self).get_context_data(**kwargs)
        context['faculty_pk'] = self.kwargs['pk']
        return context

class DeleteDepartmentUser(LoginRequiredMixin, DeleteView):

    model = User

    def get_success_url(self):
        faculty_pk = self.kwargs.get('faculty_pk')
        return reverse_lazy('schools:view-department', args=(faculty_pk,))

    def post(self, request, *args, **kwargs):
        if 'cancel' in request.POST:
            faculty_pk = kwargs.get('faculty_pk')
            return HttpResponseRedirect(reverse('schools:view-department', args=(faculty_pk,)))
        else:
            return super(DeleteDepartmentUser, self).post(request, *args, **kwargs)

    def get_context_data(self, **kwargs):
        context = super(DeleteDepartmentUser, self).get_context_data(**kwargs)
        context['user_pk'] = self.kwargs['pk']
        context['faculty_pk'] = self.kwargs['faculty_pk']
        return context


class UserChangeDepartment(LoginRequiredMixin, TemplateView):
    template_name = 'schools/change-department.html'

    def get(self, request, *args, **kwargs):

        user = request.user
        user_faculties = user.get_user_department_membership()

        department_form = DepartmentForm()
        department_form.set_queryset(user_faculties)
        department_form.set_initial(user.faculty)

        context = {
            'department_form': department_form
        }

        return render(request, self.template_name, context)

    def post(self, request, *args, **kwargs):

        if 'save' in request.POST:
            user = request.user
            department_form = DepartmentForm(request.POST)

            if department_form.is_valid():
                faculty = department_form.clean_faculty()
                user.faculty = faculty
                user.save()

        return redirect('core_nav:settings')

class UserEditDepartments(LoginRequiredMixin, TemplateView):
    template_name = 'schools/edit-user-departments.html'

    def get(self, request, *args, **kwargs):
        user = request.user
        user_faculties = user.get_user_department_membership()

        context = {
            'user_faculties': user_faculties,
            'current_user_faculty': user.faculty
        }

        return render(request, self.template_name, context)


class UserJoinDepartment(LoginRequiredMixin, TemplateView):
    template_name = 'schools/user-join-department.html'

    def get(self, request, *args, **kwargs):

        department_form = DepartmentForm()
        school_faculties = Faculty.objects.get_school_faculties_non_member(request.user)
        department_form.set_queryset(school_faculties)

        context = {
            'department_form': department_form
        }

        return render(request, self.template_name, context)

    def post(self, request, *args, **kwargs):

        if 'save' in request.POST:

            user = request.user
            department_form = DepartmentForm(request.POST)

            if department_form.is_valid():
                faculty = department_form.clean_faculty()
                user.member_of_faculties.add(faculty)
                user.save()

                return redirect('schools:user-edit-departments')

            context = {
                'department_form': department_form
            }

            return render(request, self.template_name, context)

        return redirect('schools:user-edit-departments')


def user_leave_department(request, *args, **kwargs):
    faculty_pk = kwargs.get('faculty_pk')

    user = request.user

    faculty = Faculty.objects.get_faculty(faculty_pk)
    user.member_of_faculties.remove(faculty)


    user.save()

    return redirect('schools:user-edit-departments')


class AccountExpired(TemplateView):

    template_name = 'schools/account-expired.html'

    def get(self, request, *args, **kwargs):

        return render(request, self.template_name)

class UploadSchoolBadge(LoginRequiredMixin, TemplateView):

    template_name = 'schools/upload-school-badge.html'

    def get(self, request, *args, **kwargs):
        current_user = request.user
        school_badge_url = common_helpers.get_school_badge_url(current_user.school)

        school_badge_form = SchoolBadgeForm()

        context = {
            'school_badge_url': school_badge_url,
            'school_badge_form': school_badge_form
        }

        return render(request, self.template_name, context)

    def post(self, request, *args, **kwargs):
        if request.method == 'POST':

            current_user = request.user
            school = current_user.school
            school_badge_form = SchoolBadgeForm(request.POST, request.FILES)

            if school_badge_form.is_valid():
                cleaned_form = school_badge_form.cleaned_data
                school_badge = cleaned_form.get('school_badge')

                school.school_badge = school_badge
                school.save()

        return HttpResponseRedirect(request.META.get('HTTP_REFERER'), '/')
